@@ -62,7 +62,24 @@ def cli():
 
 
 def generate_app(app_name, details_file=None, install=False, app_type="certified",
-                 version="1.3", adb_path=None, app_path=None, all_perm=None):
+                 version="1.3", adb_path=None, app_path=None, all_perm=False):
+    """
+    Generates the app and optionally installs it.
+
+    :param app_name: name of the app
+    :param details_file: the path to the json file holding the permissions/details
+    :param install: Optional, if passed as True, we will install the app
+    :param app_type: Optional, type of app. Either "hosted", "certified" or 
+                    "privilged". Default is "certified"
+    :param version: Optional, the b2g version. Default is "1.3"
+    :param adb_path: Optional, path to adb executable. By default, we assume
+                    'adb' is on the path.
+    :param app_path: Optional, if passed, the app's zip file will be
+                     stored at the given location. By default, we will put
+                     it in the current working dirctory as 'app.zip'
+    :param all_perm: Optional, if passed, gives the app all permissions.
+                     By default this is false. 
+    """
     details = create_details(version, details_file, all_perm)
     manifest = create_manifest(app_name, details, app_type,
                                version)
@@ -196,7 +213,7 @@ def package_app(manifest, path):
     return app_path
 
 
-def install_app(app_name, app_path, adb_path=None):
+def install_app(app_name, app_path, adb_path=None, script_timeout=5000):
     dm = None
     if adb_path:
         dm = mozdevice.DeviceManagerADB(adbPath=adb_path)
@@ -229,7 +246,7 @@ def install_app(app_name, app_path, adb_path=None):
     m = Marionette()
     m.start_session()
     m.set_context("chrome")
-    m.set_script_timeout(5000)
+    m.set_script_timeout(script_timeout)
     m.execute_async_script(script)
     m.delete_session()
 
